/// <reference types="node" />
import HTTPS from "node:https";
import { SequentialBucket } from "./bucket";
import type { Webhook } from "../structures/Webhook";
import type { FileAttachment } from "../util/types.message";
/**
 * The request handler for REST requests.
 * @private
 */
export declare class RequestHandler {
    /** The base URL for all requests. */
    readonly baseURL: string;
    /** The user agent for all requests. */
    readonly userAgent: string;
    /** The ratelimits per route. */
    readonly ratelimits: Record<string, SequentialBucket>;
    /** The amount of time a request will timeout. */
    readonly requestTimeout: number;
    /** TheHTTP agent used in the request handler. */
    readonly agent?: HTTPS.Agent;
    /** The latency reference for the handler. */
    readonly latencyRef: LatencyRef;
    /** Whether the handler is globally blocked. */
    globalBlock: boolean;
    /** The request queue. */
    readonly readyQueue: any[];
    /** The creator that initialized the handler. */
    private readonly _webhook;
    /** @param webhook The instantiating creator. */
    constructor(webhook: Webhook);
    /** Unblocks the request handler. */
    globalUnblock(): void;
    /**
     * Make an API request
     * @param method Uppercase HTTP method
     * @param url URL of the endpoint
     * @param body Request payload
     * @param file The file(s) to send
     * @param token Authorization token
     * @param reason The reason for the request (for endpoints that support it)
     */
    request(method: string, url: string, body?: any, file?: FileAttachment | FileAttachment[], token?: string, reason?: string, _route?: string, short?: boolean): Promise<any>;
    routefy(url: string, method: string): string;
    toString(): string;
}
/** @hidden */
declare type LatencyRef = {
    latency: number;
    offset?: number;
    raw: number[];
    timeOffset: number;
    timeOffsets: number[];
    lastTimeOffsetCheck: number;
};
export {};
