"use strict";
// Derived from functionality within Eris and slash-create
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultipartData = void 0;
const CR = "\r\n";
class MultipartData {
    constructor() {
        this.segments = [];
        this.disposition = this.header("Content-Disposition", "form-data");
    }
    get boundary() {
        return "-------------discord-multihook";
    }
    header(name, value) {
        return `${CR}${name}: ${value};`;
    }
    field(name, value) {
        return `${name}="${value}"`;
    }
    get contentType() {
        return `multipart/form-data; boundary=${this.boundary}`;
    }
    addSegment(segment) {
        this.segments.push(Buffer.from(segment));
        return this;
    }
    attach(fieldName, data, filename) {
        if (data === undefined) {
            return;
        }
        if (Object.isFrozen(this)) {
            throw new Error("Cannot add segments to a finished MultipartData");
        }
        let segment = CR +
            `--${this.boundary}${this.disposition} ${this.field("name", fieldName)}`;
        if (filename) {
            segment += `; ${this.field("filename", filename)}`;
        }
        segment += CR + CR;
        if (data instanceof Buffer) {
            segment += this.header("Content-Type", "application/octet-stream");
        }
        else if (typeof data === "object") {
            segment += this.header("Content-Type", "application/json");
            data = JSON.stringify(data);
        }
        else {
            data = String(data);
        }
        return this.addSegment(segment + CR + CR).addSegment(data);
    }
    finish() {
        if (!Object.isFrozen(this)) {
            this.addSegment(CR + `--${this.boundary}--`);
            Object.freeze(this);
        }
        return this.segments;
    }
}
exports.MultipartData = MultipartData;
