import { User } from "./User";
import type { Webhook } from "./Webhook";
import type { ComponentRow } from "../util/types.components";
import type { Embed } from "../util/types.embed";
import type { AttachmentData, EditMessageOptions, MessageData, MessageFlags } from "../util/types.message";
export declare class Message {
    #private;
    readonly _webhook: Webhook;
    /** The ID of the message. */
    readonly id: string;
    /** The author of the message. */
    readonly author: User;
    /** If the webhook is application-owned, this will return the application's ID. */
    readonly applicationID?: string;
    /** File attachments on the message. */
    attachments?: AttachmentData[];
    /**
     * The channel this message belongs to.
     * * Text
     * * Voice
     * * News
     * * Thread
     *
     * *Webhooks do not have enough information to determine the channel type by themselves.*
     */
    readonly channelID: string;
    /** Attached message components */
    components?: ComponentRow[];
    /** String content of the message. */
    content?: string;
    /** When the message was edited. (null if never) */
    editedTimestamp?: string;
    /** Embeds attached to the message. */
    embeds?: Embed[];
    /** Message flags bitfield. */
    flags?: MessageFlags;
    /** Is this message pinned? (Applies to all channel types). */
    pinned?: boolean;
    /** Any user entries that were mentioned in the message (sent from Discord). */
    mentions?: User[];
    /** Any roles that were mentioned in the message (sent from Discord). */
    mentionsRoles?: string[];
    /** Whether this message mentions everyone. */
    mentionEveryone?: boolean;
    /** (Forum Post / Public Thread) Approximate position of message entry in a thread. */
    position?: number;
    /** When the message was created. */
    readonly timestamp: string;
    /** Whether the message was sent with text-to-speech enabled. */
    tts: boolean;
    /** The webhook that sent the message. */
    webhookID?: string;
    constructor(webhook: Webhook, data: MessageData, inThread?: boolean);
    /** @hidden */
    _patch(data: Message | MessageData): void;
    fetch(): Promise<Message>;
    /** */
    edit(content: string | EditMessageOptions, options: EditMessageOptions): Promise<Message>;
    /**
     * Removes the message, uses the channelID to target the thread... if it is in one.
     * @returns void
     */
    delete(): Promise<void>;
}
