"use strict";
// #region Imports
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _Message_instances, _Message_inThread, _Message_destroy;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Message = void 0;
// Local classes
const User_1 = require("./User");
// #endregion
class Message {
    constructor(webhook, data, inThread = false) {
        _Message_instances.add(this);
        _Message_inThread.set(this, void 0);
        this._webhook = webhook;
        __classPrivateFieldSet(this, _Message_inThread, inThread, "f");
        this.id = data.id;
        this.author = new User_1.User(this._webhook, data.author);
        this.channelID = data.channel_id;
        this.timestamp = data.timestamp;
        // this.type = data.type;
        this.tts = data.tts;
        this.webhookID = data.webhook_id;
        this._patch(data);
    }
    /** @hidden */
    _patch(data) {
        if (data instanceof Message) {
            if (this.editedTimestamp !== data.editedTimestamp) {
                this.editedTimestamp = data.editedTimestamp;
            }
            if (this.mentionEveryone !== data.mentionEveryone) {
                this.mentionEveryone = data.mentionEveryone;
            }
            this.mentions = data.mentions;
            this.mentionsRoles = data.mentionsRoles;
        }
        else {
            if (data.edited_timestamp) {
                this.editedTimestamp = data.edited_timestamp;
            }
            if (data.mention_everyone) {
                this.mentionEveryone = data.mention_everyone;
            }
            if (data.webhook_id) {
                this.webhookID = data.webhook_id;
            }
            if (data.mentions) {
                this.mentions = data.mentions.map((mention) => new User_1.User(this._webhook, mention));
            }
            if (data.mentions_roles) {
                this.mentionsRoles = data.mentions_roles;
            }
        }
        if (data.attachments) {
            this.attachments = data.attachments;
        }
        if (data.content) {
            this.content = data.content;
        }
        if (data.embeds) {
            this.embeds = data.embeds;
        }
        if (data.pinned) {
            this.pinned = data.pinned;
        }
        if (data.position) {
            this.position = data.position;
        }
        if (data.tts) {
            this.tts = data.tts;
        }
    }
    async fetch() {
        const data = await this._webhook.fetchMessage(this.id);
        this._patch(data);
        return this;
    }
    /** */
    async edit(content, options) {
        if (__classPrivateFieldGet(this, _Message_inThread, "f")) {
            if (typeof content === "object") {
                content = { ...content, threadID: this.channelID };
            }
            else {
                options = { ...options, threadID: this.channelID };
            }
        }
        const data = await this._webhook.editMessage(this.id, content, options);
        this._patch(data);
        return data;
    }
    /**
     * Removes the message, uses the channelID to target the thread... if it is in one.
     * @returns void
     */
    async delete() {
        await this._webhook.deleteMessage(this.id, __classPrivateFieldGet(this, _Message_inThread, "f") ? this.channelID : undefined);
        __classPrivateFieldGet(this, _Message_instances, "m", _Message_destroy).call(this);
    }
}
exports.Message = Message;
_Message_inThread = new WeakMap(), _Message_instances = new WeakSet(), _Message_destroy = function _Message_destroy() {
    // Unknown, unref to dispose of
};
