import { Webhook } from "./Webhook";
import type { AvatarSize, ImageFormat, UserData, UserFlags } from "../util/types.common";
/**
 * Represents a Discord user.
 *
 * Webhooks *sometimes* have enough information to determine what type of user the data represents (`~#publicFlags`, `~#avatarDecoration`).
 */
export declare class User {
    private readonly webhook;
    /** The avatar of the user. */
    avatar?: string;
    /** The avatar decoration of the user (available for user mentions). */
    avatarDecoration?: string;
    /** Whether the user is a bot. */
    bot: boolean;
    /** The discriminator of the user. */
    discriminator: string;
    /** The ID of the user. */
    id: string;
    /** The username of the user. */
    username: string;
    /** The public flags that the user has. */
    publicFlags?: UserFlags;
    constructor(webhook: Webhook, user: UserData);
    /**
     * The tag of the user.
     */
    get tag(): string;
    /**
     * The mention of the user.
     */
    get mention(): string;
    get avatarURL(): string;
    get defaultAvatarURL(): string;
    dynamicAvatarURL(format: ImageFormat, size: AvatarSize): string;
    toString(): string;
}
