"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.User = void 0;
// Local constants & types
const constants_1 = require("../util/constants");
/**
 * Represents a Discord user.
 *
 * Webhooks *sometimes* have enough information to determine what type of user the data represents (`~#publicFlags`, `~#avatarDecoration`).
 */
class User {
    constructor(webhook, user) {
        this.webhook = webhook;
        // Guaranteed data fields
        this.bot = user.bot;
        this.discriminator = user.discriminator;
        this.id = user.id;
        this.username = user.username;
        // Optional (or null) data fields
        if (user.avatar) {
            this.avatar = user.avatar;
        }
        if (user.public_flags) {
            this.publicFlags = user.public_flags;
        }
        if (user.avatar_decoration) {
            this.avatarDecoration = user.avatar_decoration;
        }
    }
    /**
     * The tag of the user.
     */
    get tag() {
        return `${this.username}#${this.discriminator}`;
    }
    /**
     * The mention of the user.
     */
    get mention() {
        return `<@${this.id}>`;
    }
    get avatarURL() {
        if (!this.avatar) {
            return this.defaultAvatarURL;
        }
        const format = this.avatar.startsWith("a_") ? "gif" : "png";
        return constants_1.ROUTER.cdn.avatar(this.id, this.avatar, format);
    }
    get defaultAvatarURL() {
        return constants_1.ROUTER.cdn.defaultAvatar(Number(this.discriminator) % 5);
    }
    dynamicAvatarURL(format, size) {
        if (!this.avatar) {
            return this.defaultAvatarURL;
        }
        if (this.avatar.startsWith("a_")) {
            format = "gif";
        }
        return constants_1.ROUTER.cdn.avatar(this.id, this.avatar, format, size);
    }
    toString() {
        return `${this.tag} (${this.id})`;
    }
}
exports.User = User;
