/// <reference types="node" />
import EventEmitter from "node:events";
import { Message } from "./Message";
import { RequestHandler } from "../rest/handler";
import type { EditWebhookOptions, WebhookOptions } from "../util/types.webhook";
import type { EditMessageOptions, MessageOptions } from "../util/types.message";
export declare class Webhook extends EventEmitter {
    #private;
    /** @hidden */
    protected requestHandler: RequestHandler;
    options: WebhookOptions;
    id: string;
    token: string;
    applicationID?: string;
    avatar?: string;
    channelID?: string;
    guildID?: string;
    name?: string;
    static from(target: URL | string, options?: Omit<WebhookOptions, "id" | "token">): Webhook;
    constructor(options: WebhookOptions);
    fetch(): Promise<this>;
    edit(options: EditWebhookOptions): Promise<this>;
    /**
     *
     * @param id The ID of the message to fetch
     * @param threadID The ID of the thread to fetch the message from
     * @returns The message
     *
     * @future Optional message caching (likely breaking change, to include the possibility of not providing `threadID`)
     *
     * Possibility to provide the 2nd argument as an object to allow the bypass to force a request.
     * `{ threadID: string, forceFetch: boolean }`
     */
    fetchMessage(id: string, threadID?: string): Promise<Message>;
    /**
     *
     * @param content The content of the message
     * @param options The options for the message
     * @returns The created message
     */
    sendMessage(content: string | MessageOptions, options?: MessageOptions): Promise<Message>;
    editMessage(messageID: string, content: string | EditMessageOptions, options?: EditMessageOptions): Promise<Message>;
    deleteMessage(messageID: string, threadID?: string): Promise<void>;
    /**
     * This removes the webhook from the channel, and makes the class instance unusable from this point.
     * @returns void
     */
    delete(): Promise<void>;
}
